@@ -1,5 +1,3 @@
-library(testthat)
-library(basket)
 
 context("Update models")
 
@@ -9,7 +7,8 @@ data(vemu_wide)
 mh1 <- mem_mcmc(responses = vemu_wide$responders, 
                 size = vemu_wide$evaluable,
                 name= vemu_wide$baskets,
-                p0 = c(0.15, 0.15, 0.15, 0.2, 0.15, 0.15))
+                p0 = c(0.15, 0.15, 0.15, 0.2, 0.15, 0.15),
+                mcmc_iter = 100)
 
 mh2 <- update_p0(mh1, 0.25)
 
